Release notes
#############

Here you can find release notes for all released versions of Lewis.

.. toctree::
    :maxdepth: 1

    release_1_3_1
    release_1_3_0
    release_1_2_2
    release_1_2_1
    release_1_2_0
    release_1_1_1
    release_1_1_0
    release_1_0_3
    release_1_0_2
    release_1_0_1
    release_1_0_0
